==> cyphermed-2.1.21-py3-none-any.whl: cyphermed/api/users/delete_user_by_id.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.success import Success
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: str,
    *,
    permanent: Union[Unset, bool] = False,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["permanent"] = permanent

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "delete",
        "url": f"/v2/users/{user_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Success]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Success.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Success]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = False,
) -> Response[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        permanent=permanent,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = False,
) -> Optional[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return sync_detailed(
        user_id=user_id,
        client=client,
        permanent=permanent,
    ).parsed


async def asyncio_detailed(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = False,
) -> Response[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        permanent=permanent,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = False,
) -> Optional[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return (
        await asyncio_detailed(
            user_id=user_id,
            client=client,
            permanent=permanent,
        )
    ).parsed

==> cyphermed-2.2.0-py3-none-any.whl: cyphermed/api/users/delete_user_by_id.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.success import Success
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: str,
    *,
    permanent: Union[Unset, bool] = UNSET,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["permanent"] = permanent

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "delete",
        "url": f"/v2/users/{user_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Success]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Success.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Success]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = UNSET,
) -> Response[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        permanent=permanent,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = UNSET,
) -> Optional[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return sync_detailed(
        user_id=user_id,
        client=client,
        permanent=permanent,
    ).parsed


async def asyncio_detailed(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = UNSET,
) -> Response[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Success]
    """

    kwargs = _get_kwargs(
        user_id=user_id,
        permanent=permanent,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    user_id: str,
    *,
    client: AuthenticatedClient,
    permanent: Union[Unset, bool] = UNSET,
) -> Optional[Success]:
    """Delete User By Id

     Delete a user by ID

    Args:
        user_id (str):
        permanent (Union[Unset, bool]): Permanently deletes the user instead of just deactivating
            them

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Success
    """

    return (
        await asyncio_detailed(
            user_id=user_id,
            client=client,
            permanent=permanent,
        )
    ).parsed
